@@ -412,6 +412,10 @@ gpm_device_state_to_localised_string (UpDeviceState state)
 		/* TRANSLATORS: battery state */
 		state_string = _("Waiting to discharge");
 		break;
+	case UP_DEVICE_STATE_UNKNOWN:
+		/* TRANSLATORS: battery state */
+		state_string = _("Unknown");
+		break;
 	default:
 		g_assert_not_reached ();
 		break;
@@ -1814,7 +1818,7 @@ static gboolean
 gpm_stats_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
 {
 	g_application_release (G_APPLICATION (application));
-	return FALSE;
+	return TRUE;
 }
 
 /**
